Skip to main content

HL7 to JSON Format Converter

A Python package to convert HL7 v2 messages to JSON format.

Installation from source

Extract hl7-conversion-{tag}.tar.gz file in your working directory.

Change directory to project root:

cd hl7-conversion

Create and activate python virtual env:

python3.8 -m venv .venv
source .venv/bin/activate
pip install --upgrade pip

Install hl7-conversion package:

pip install -e .

CLI usage

Type --help after commands to see full list of options

$ hl7 --help
Usage: hl7 [OPTIONS] COMMAND [ARGS]...

  HL7 to JSON format converter

Options:
  --version  Show the version and exit.
  --help     Show this message and exit.

Commands:
  tojson  Convert given HL7 message to JSON format 
$ hl7 tojson --help
Usage: hl7 tojson [OPTIONS] INPUT

  Convert given HL7 message to JSON format

Options:
  -o, --output FILENAME  Output file path
  --help                 Show this message and exit.

Example:

hl7 tojson input.txt -o output.txt

In this example, the command will try to read the input HL7 message from input.txt file and write the converted JSON output to output.txt file.

Programmatic usage

HL7Client

HL7Client.hl7tojsonconvert

Arguments:

  • message (str): Given HL7 message in string format.

See tests/test_client for usage examples.

Metadata

Release files for hl7-conversion 0.1.1

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for hl7-conversion 0.1.1
File Size Uploaded Provenance Actions
hl7-conversion-0.1.1.tar.gz 3.1 kB Without provenance Details for hl7-conversion-0.1.1.tar.gz

Built distribution (wheel)

Table of built distributions (wheels) for hl7-conversion 0.1.1
File Interpreter ABI Platform Actions
hl7_conversion-0.1.1-py3-none-any.whl Python 3 none any Details for hl7_conversion-0.1.1-py3-none-any.whl

Total release size: 7.4 kB

Release files / hl7-conversion-0.1.1.tar.gz

Download URL hl7-conversion-0.1.1.tar.gz
Size 3.1 kB
Tags Source
SHA-256 checksum
How to use checksums
46c572f3e0c5e9c64c20516610c4a95c1e26c4c35e4f96c9e2c9d899e1a39a54
BLAKE2b-256 checksum
How to use checksums
7a141ecdc84b15ae8f3cc6b88d1014d6dc284cab8bb185b265a7e9ddfe75bae7
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/4.0.0 CPython/3.8.10

Release files / hl7_conversion-0.1.1-py3-none-any.whl

Download URL hl7_conversion-0.1.1-py3-none-any.whl
Size 4.3 kB
Tags Python 3
SHA-256 checksum
How to use checksums
b3f40aaceef1b1585e026a0129b0479478da3d8783201c2ca8cf335e98c80c16
BLAKE2b-256 checksum
How to use checksums
dcc831099d1eeedb6a3657294d69d96158f1328db6b75ecc5ab9c499e05531dd
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/4.0.0 CPython/3.8.10

Security for hl7-conversion 0.1.1

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

No provenance found

None of the files in this release were uploaded with provenance metadata.

A note on package security

PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.

To learn more about protecting yourself from malicious actors, visit our package security documentation.

Release history Release notifications | RSS feed

This release

0.1.1 This release

2 release files No provenance

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page